@@ -287,7 +287,10 @@ def get_composite_pnl_plot(delta, ret, fig_return=False, alpha=False, **kwargs):
     ind_long[ind_long < 0] = 0
     ind_short[ind_short > 0] = 0
 
-    indicator_og = pd.DataFrame(100.0 / len(indicator.columns), index=indicator.index, columns=indicator.columns)
+    # indicator_og = pd.DataFrame(100.0 / len(indicator.columns), index=indicator.index, columns=indicator.columns)
+    indicator_og = ret.copy()
+    indicator_og[~ np.isnan(indicator_og)] = 100
+    indicator_og = indicator_og.div(indicator_og.count(axis=1), axis=0)
 
     # plot
     fig = plt.figure(figsize=(20, 12))
