@@ -114,10 +114,8 @@ def er(serie, window):
     return x / y
 
 
-def kama(serie, window):
+def kama(serie, window, fast_win = 2, slow_win = 30):
     er_ = er(serie, window)
-    fast_win = 2
-    slow_win = 30
     fast_alpha = 2 / (fast_win + 1)  # = 0,6667
     slow_alpha = 2 / (slow_win + 1)  # = 0,0645
     sc = pd.Series((er_ * (fast_alpha - slow_alpha) + slow_alpha) ** 2)  ## smoothing constant
@@ -194,4 +192,42 @@ def next_trading_day(timestamp):
         return dt
     else:
         print('input type should be datetime.datetime or datetime.date')
-        return None
\ No newline at end of file
+        return None
+
+
+def get_settle_day(s):
+    """
+    :param s: a str: 'IF1601', 'IC1701'
+    :return: datetime.datetime: settle day
+    """
+    def str_clip(s):
+        for i in range(len(s)):
+            if s[i].isdecimal():
+                break
+        return s[i:] if i >= 0 else ''
+
+    sd = datetime.strptime(f'20{str_clip(s)}01', '%Y%m%d')
+    wd = sd.weekday()
+    if wd <= 4:
+        settle_day = datetime(sd.year, sd.month, 5 - wd + 14)
+    else:
+        settle_day = datetime(sd.year, sd.month, 7 - wd + 19)
+
+    if cc.is_holiday(settle_day):
+        i = 3
+        while True:
+            temp = settle_day + datetime.timedelta(days=i)
+            if cc.is_workday(temp):
+                settle_day = temp
+                break
+            else:
+                i += 1
+    return settle_day
+
+
+def get_rank_delta(factor):
+    delta = pd.DataFrame(factor)
+    delta = delta.rank(axis=1)
+    delta = delta.sub(delta.mean(axis=1), axis=0)
+    delta = delta.div(delta.abs().sum(axis=1), axis=0) * 100
+    return delta
